@@ -78,6 +78,8 @@ G_DEFINE_AUTOPTR_CLEANUP_FUNC (FlatpakInstallation, g_object_unref)
 
 FLATPAK_EXTERN const char  *flatpak_get_default_arch (void);
 
+FLATPAK_EXTERN const char *const *flatpak_get_supported_arches (void);
+
 FLATPAK_EXTERN FlatpakInstallation *flatpak_installation_new_system (GCancellable *cancellable,
                                                                      GError      **error);
 FLATPAK_EXTERN FlatpakInstallation *flatpak_installation_new_user (GCancellable *cancellable,
@@ -249,5 +251,15 @@ FLATPAK_EXTERN gboolean          flatpak_installation_update_appstream_sync (Fla
                                                                              gboolean            *out_changed,
                                                                              GCancellable        *cancellable,
                                                                              GError             **error);
+FLATPAK_EXTERN GPtrArray    *    flatpak_installation_list_remote_related_refs_sync (FlatpakInstallation *self,
+                                                                                     const char          *remote_name,
+                                                                                     const char          *ref,
+                                                                                     GCancellable        *cancellable,
+                                                                                     GError             **error);
+FLATPAK_EXTERN GPtrArray    *    flatpak_installation_list_installed_related_refs_sync (FlatpakInstallation *self,
+                                                                                        const char          *remote_name,
+                                                                                        const char          *ref,
+                                                                                        GCancellable        *cancellable,
+                                                                                        GError             **error);
 
 #endif /* __FLATPAK_INSTALLATION_H__ */
